# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))
import clustergram  # noqa

# -- Project information -----------------------------------------------------

project = "Clustergram"
copyright = "Martin Fleischmann"
author = "Martin Fleischmann"

version = clustergram.__version__
# The full version, including alpha/beta/rc tags
release = version


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "numpydoc",
    "sphinx.ext.autosummary",
    "myst_nb",
    "sphinx_copybutton",
]

nb_execution_mode = "force"
nb_execution_allow_errors = True
nb_execution_excludepatterns = ["methods.ipynb"]

autosummary_generate = True
numpydoc_show_class_members = True
numpydoc_class_members_toctree = False
add_module_names = False

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_book_theme"
html_title = "clustergram"
# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

# html_css_files = [
#     "custom.css",
# ]
html_logo = "_static/logo.svg"

html_theme_options = {
    "repository_url": "https://github.com/martinfleis/clustergram",
    "use_repository_button": True,
    "use_download_button": False,
    "use_fullscreen_button": False,
    "use_issues_button": True,
    "repository_branch": "main",
    "path_to_docs": "doc",
    "launch_buttons": {"binderhub_url": "https://mybinder.org/"},
}
